@@ -29,8 +29,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 824 $ 
+#                       from $Date: 2020-12-17 13:37:27 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -38,6 +38,7 @@ from GatoGlobals import AnimationParameters, gInfinity, NoSuchVertexError, NoSuc
 from DataStructures import VertexLabeling, Queue, Stack, PriorityQueue
 from Graph import SubGraph
 import copy
+import logging
 #import sets
 
 g = AnimationParameters
@@ -393,7 +394,7 @@ class AnimatedVertexQueue(Queue):
     def Top(self):
         v = Queue.Top(self)
         self.Animator.SetVertexColor(v, self.ColorOff)
-        if self.lastRemoved is not None:
+        if self.lastRemoved != None:
             self.Animator.SetVertexFrameWidth(self.lastRemoved, g.VertexFrameWidth)
         self.Animator.SetVertexFrameWidth(v, g.ActiveVertexFrameWidth)
         self.lastRemoved = v 
@@ -403,7 +404,7 @@ class AnimatedVertexQueue(Queue):
         for v in self.contents:
             self.Animator.SetVertexColor(v, self.ColorOff)
         Queue.Clear(self) 
-        if self.lastRemoved is not None:
+        if self.lastRemoved != None:
             self.Animator.SetVertexFrameWidth(self.lastRemoved,g.VertexFrameWidth)
             self.lastRemoved = None
             
@@ -434,7 +435,7 @@ class AnimatedVertexPriorityQueue(PriorityQueue):
     def DeleteMin(self):
         v = PriorityQueue.DeleteMin(self)
         self.Animator.SetVertexColor(v, self.ColorOff)
-        if self.lastRemoved is not None:
+        if self.lastRemoved != None:
             self.Animator.SetVertexFrameWidth(self.lastRemoved, g.VertexFrameWidth)
         self.Animator.SetVertexFrameWidth(v, g.ActiveVertexFrameWidth)
         self.lastRemoved = v 
@@ -464,7 +465,7 @@ class AnimatedVertexStack(Stack):
     def Pop(self):
         v = Stack.Pop(self)
         self.Animator.SetVertexColor(v, self.ColorOff)
-        if self.lastRemoved is not None:
+        if self.lastRemoved != None:
             self.Animator.SetVertexFrameWidth(self.lastRemoved, g.VertexFrameWidth)
         self.Animator.SetVertexFrameWidth(v, g.ActiveVertexFrameWidth)
         self.lastRemoved = v 
@@ -474,7 +475,7 @@ class AnimatedVertexStack(Stack):
         for v in self.contents:
             self.Animator.SetVertexColor(v, self.ColorOff)
         Stack.Clear(self)
-        if self.lastRemoved is not None:
+        if self.lastRemoved != None:
             self.Animator.SetVertexFrameWidth(self.lastRemoved, g.VertexFrameWidth)
             self.lastRemoved = None
             
@@ -631,14 +632,14 @@ class AnimatedSubGraph(SubGraph):
             self.Animator.RaiseEdge(tt,hh)
             self.Animator.DefaultInfo()
             return tt,hh
-        except NoSuchVertexError, NoSuchEdgeError:
+        except (NoSuchVertexError, NoSuchEdgeError):
             return
 
     def AddSubGraph(self, G):
         """ Add subgraph G to self. Will do nothing if self and G 
             have distinct supergraphs """
         if self.superGraph != G.superGraph:
-            log.error("AddSubGraph: distinct superGraphs")
+            logging.error("AddSubGraph: distinct superGraphs")
             return
         
         for v in G.Vertices():
@@ -648,7 +649,7 @@ class AnimatedSubGraph(SubGraph):
         for t,h in G.Edges():
             SubGraph.AddEdge(self, t, h)
         self.Animator.SetEdgesColor(G.Edges(),self.Color) 
-        #print "Just called setEdgesColor animator is ", self.Animator.__class__.__name__
+        #logging.debug("Just called setEdgesColor animator is %s" % self.Animator.__class__.__name__)
         self.Animator.SetAllVerticesColor(self.Color, graph=G)
         self.RaiseEdges()
         self.Animator.DefaultInfo()
@@ -670,7 +671,7 @@ class AnimatedSubGraph(SubGraph):
         try:
             SubGraph.DeleteEdge(self,t,h)
             self.Animator.SetEdgeColor(t,h,"black")
-        except NoSuchVertexError, NoSuchEdgeError:
+        except (NoSuchVertexError, NoSuchEdgeError):
             return
             
     def Clear(self, color="grey"):
@@ -693,7 +694,7 @@ class AnimatedSubGraph(SubGraph):
             SubGraph.AddEdge(self,tail,head)
             self.Animator.SetEdgeColor(tail,head,self.Color)
             self.Animator.DefaultInfo()
-        except NoSuchVertexError, NoSuchEdgeError:
+        except (NoSuchVertexError, NoSuchEdgeError):
             return
             
             
