@@ -30,8 +30,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 826 $ 
+#                       from $Date: 2020-12-17 16:18:34 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -44,7 +44,7 @@ import copy
 import sys
 import os
 import types
-
+import logging
 
 def typed_assign(var, val):
     result = type(var)(val)
@@ -207,10 +207,10 @@ class TkPopupSelector:
         keys = self.value2pop.keys()
         keys.sort()
         pops = map(lambda x: value2pop[x], keys)
-        #log.debug("pops = %s" % pops)
+        #logging.debug("pops = %s" % pops)
         args = (master, self.popupvalue) + tuple(pops)
         
-        self.tkwidget = apply(OptionMenu, args)
+        self.tkwidget = OptionMenu(*args)
         self.tkwidget.config(height=1, width=width)
         
     def tkWidget(self):
@@ -239,7 +239,7 @@ class TkStringPopupSelector:
             
         width = max(map(len, self.strings))
         args = (master, self.popupvalue) + tuple(self.strings)
-        self.tkwidget = apply(OptionMenu, args)
+        self.tkwidget = OptionMenu(*args)
         self.tkwidget.config(height=1, width=width)
         
     def tkWidget(self):
@@ -268,7 +268,7 @@ class TkColorSelector:
         
     def editColor(self, event):
         color = askcolor(self.color)[1]
-        if color is not None:
+        if color != None:
             self.set(color)
             
     def tkWidget(self):
