@@ -27,8 +27,8 @@
 #       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 826 $ 
+#                       from $Date: 2020-12-17 16:18:34 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -79,9 +79,9 @@ class AutoScrollbar(Scrollbar):
             self.grid()
         Scrollbar.set(self, lo, hi)
     def pack(self, **kw):
-        raise TclError, "cannot use pack with this widget"
+        raise TclError("cannot use pack with this widget")
     def place(self, **kw):
-        raise TclError, "cannot use place with this widget"
+        raise TclError("cannot use place with this widget")
 
 
 class AutoScrolledText(Text):
@@ -229,15 +229,6 @@ class HTMLWriter(formatter.DumbWriter):
     def send_label_data(self, data):
         self.write(self.indent + data + ' ')
 
-    #def send_line_break(self):
-    #    print "send_line_break"
-    #    #pass
-
-    #def send_paragraph(self,blankline):
-    #    print "send_paragraph", blankline
-
-        
-
         
 class MyHTMLParser(htmllib.HTMLParser):
     """ Basic parser with image support added. output is supposed to be
