@@ -26,8 +26,8 @@
 #       License along with this library; if not, write to the Free
 #       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 826 $ 
+#                       from $Date: 2020-12-17 16:18:34 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -38,6 +38,7 @@ import codecs
 import StringIO
 import urllib2
 import xml.dom.minidom
+import logging
 import Gato
 import Graph
 import GraphUtil
@@ -136,7 +137,7 @@ class GatoStorageLocationTest:
     """
     def __init__(self):
         l=GatoStorageLocation("bla")
-        print "human readable: %s, python representation %s"%(l,repr(l))
+        logging.info("human readable: %s, python representation %s"%(l,repr(l)))
         
         
 class GatoDirBranch(TreeWidget.DirBranch):
@@ -266,7 +267,7 @@ class xmlAlgorithmElement:
         if os.access(PrologFileName,os.R_OK):
             self.setProlog(file(PrologFileName).read())
         else:
-            print "Warning: could not read prolog file %s"%PrologFileName
+            logging.warning("Warning: could not read prolog file %s" % PrologFileName)
             
     def setProlog(self,text):
         """
@@ -384,7 +385,7 @@ class xmlGraphElement:
                 raise FileException("Wrong element name: %s, %s expected"
                                     %(graph.tagName,self.graphElementName))
             self.domElement=graph
-        elif issubclass(graph.__class__,Graph.Graph) and type(name) in types.StringTypes:
+        elif issubclass(graph.__class__,Graph.Graph) and type(name) in (str,):
             # initialise dom element
             self.domElement=xml.dom.minidom.Element(xmlGraphElement.graphElementName)
             self.setName(name)
@@ -476,7 +477,7 @@ class xmlGatoElement:
         else:
             newDOMElement=xml.dom.Element(xmlGraphElement.graphElementName)
         newElement=xmlGraphElement(newDOMElement)
-        if name is not None:
+        if name != None:
             newElement.setName(name)
         return newElement
         
@@ -491,7 +492,7 @@ class xmlGatoElement:
         else:
             newDOMElement=xml.dom.Element(xmlAlgorithmElement.algorithmElementName)
         newElement=xmlAlgorithmElement(newDOMElement)
-        if name is not None:
+        if name != None:
             newElement.setName(name)
         return newElement
         
@@ -687,7 +688,7 @@ class ElementDisplay(Tkinter.Frame):
             self.clearDisplay()
             return
         else:
-            if self.displayedNode is not None and self.displayedNode==node:
+            if self.displayedNode != None and self.displayedNode==node:
                 return #nothing to do
         self.clearDisplay()
         displayedWidget=None
@@ -703,7 +704,7 @@ class ElementDisplay(Tkinter.Frame):
             displayedWidget=AboutWidget(self,html_data)
             self.displayedNode=node
         else:
-            print "toDo: ",node
+            logging.warning("toDo: %s" % str(node))
             
         if displayedWidget:
             displayedWidget.pack(expand=1,fill=Tkinter.BOTH)
@@ -832,7 +833,7 @@ class GatoFileStructureWidget(TextTreeWidget.dom_structure_widget):
             if self.report_to:
                 self.report_to(event, node)
         else:
-            print event, opts
+            logging.warning("Don't know how to handls event %s and opts %s" % (event, opts))
             
     def chosenNode(self,node,register):
         """
@@ -1011,7 +1012,7 @@ class GatoFile:
             if self.mode=='r':
                 self.file=None
                 self.name=None
-                if type(myFile) in types.StringTypes:
+                if type(myFile) in (str,):
                     if os.access(myFile,os.R_OK):
                         self.file=file(myFile,"r")
                         self.name=myFile
@@ -1024,12 +1025,12 @@ class GatoFile:
                 try:
                     # pull dom out of file
                     self.dom = xml.dom.minidom.parse(self.file)
-                except xml.dom.DOMException, e:
-                    print e
+                except xml.dom.DOMException as e:
+                    logging.error("Exception raised %s" % str(e))
                     raise FileException(str(e))
                     
             elif self.mode=='w':
-                if type(myFile) in types.StringTypes:
+                if type(myFile) in (str,):
                     if os.access(myFile,os.W_OK):
                         self.file=file(myFile,"w")
                         self.name=myFile
@@ -1053,8 +1054,8 @@ class GatoFile:
         """
         # ???? write to right place????
         _thisFile=None
-        if _file is not None:
-            if type(_file) in types.StringTypes:
+        if _file != None:
+            if type(_file) in (str,):
                 _thisFile=encodedStream(file(_file,"w"))
             elif type(_file)==types.FileType:
                 _thisFile=_file
@@ -1104,7 +1105,7 @@ class GatoFile:
         creates a new (opt. unnamed)  Gato element
         """
         newElement=xmlGatoElement(self.dom.createElement(xmlGatoElement.gatoElementName))
-        if name is not None:
+        if name != None:
             newElement.setName(name)
         return newElement
         
