@@ -29,8 +29,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 821 $ 
+#                       from $Date: 2020-12-16 15:32:12 +0100 (Wed, 16 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -42,8 +42,7 @@ import GraphUtil #import ConnectedComponents, FindBipartitePartitions
 
 from math import sqrt
 import logging
-import string
-log = logging.getLogger("Graph.py")
+
 
 ################################################################################
 #
@@ -504,7 +503,7 @@ class Graph:
 
         <p>The properties %s are unknown or undetermined.</p>
         </BODY></HTML>
-        """ % (graphName, self.Order(), self.Size(), knownProps, string.join(unknownProps,', '))
+        """ % (graphName, self.Order(), self.Size(), knownProps, ", ".join(unknownProps))
         return result
 
 
@@ -587,7 +586,7 @@ class SubGraph(Graph):
         """ Add subgraph G to self. Will do nothing if self and G 
             have distinct supergraphs """
         if self.superGraph != G.superGraph:
-            log.error("AddSubGraph: distinct superGraphs")
+            logging.error("AddSubGraph: distinct superGraphs")
             return
         for e in G.Edges():
             self.AddEdge(e[0],e[1])
@@ -618,7 +617,7 @@ class SubGraph(Graph):
         
     def GetNextVertexID(self):
         """ *Internal* safeguard """
-        log.error("Induced Subgraph -> GetNextVertexID should never have been called")
+        logging.error("Induced Subgraph -> GetNextVertexID should never have been called")
         
     def Weight(self):
         """ Returns the total weight (= sum of edge weights) of subgraph """
