@@ -11,8 +11,7 @@
 #                                   
 #       Contact: alexander@schlieplab.org
 #
-
-#n
+#
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
 #       License as published by the Free Software Foundation; either
@@ -29,8 +28,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 820 $ 
+#                       from $Date: 2020-12-16 14:45:18 +0100 (Wed, 16 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -46,16 +45,11 @@ from DataStructures import Point2D, VertexLabeling, EdgeLabeling
 from AnimatedDataStructures import ComponentMaker
 import os
 import colorsys
-
 import logging
-log = logging.getLogger("GraphDisplay.py")
 
 g = GatoGlobals.AnimationParameters
 
 
-
-
-
 class ZoomVar(StringVar):
     """ *Internal* helper class to have TK update variable correspoding
         to pop-up state """
@@ -111,6 +105,10 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         self.graphInformer = None
         self.clickhandler = None
         self.highlightedPath = {}
+
+        # As logging cannot reconfigure while running, we define a file handle to output
+        # animation commands (will be called from MergedHistories only)
+        self.animationReportFileHandle = None
         
         # Used by ramazan's scaling code. Gives sizes in pixels at
         # current zoom level
@@ -706,9 +704,9 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         """
         if graph == None and vertices == None: # All vertices of graph shown
             self.canvas.itemconfig("vertices", fill=color)
-        elif graph is not None: # all vertices of induced subgraph
+        elif graph != None: # all vertices of induced subgraph
             vertices = graph.vertices
-        if vertices is not None: # all specified vertices
+        if vertices != None: # all specified vertices
             for v in vertices:
                 self.canvas.itemconfig(self.drawVertex[v], fill=color)           
         self.update()        
@@ -761,7 +759,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
     def SetEdgesColor(self, edges, color):
         """ Change color of [(tail1,head1),...] to color. No error checking! 
             Handles undirected graphs. """
-        #print "in setEdgesColor in GraphDisplay"
+        #logging.debug("in setEdgesColor in GraphDisplay")
         for tail, head in edges:
             if self.G.QDirected() == 1:
                 de = self.drawEdges[(tail,head)]
@@ -1278,7 +1276,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             self.canvas.lower(de,"vertices")
             return tail, head                
         except GatoGlobals.GraphNotSimpleError:
-            log.error("Inserting edge (%d,%d) would result in non-simple graph" % (tail,head))
+            logging.error("Inserting edge (%d,%d) would result in non-simple graph" % (tail,head))
             
             
     def DeleteEdge(self,tail,head,repaint=1):
@@ -1358,7 +1356,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             and rotated as to maximize size while still fitting on paper """ 
         bb = self.canvas.bbox("all") # Bounding box of all elements on canvas
         # Give 10 pixels room to breathe
-        print "PrintToPSFile", bb
+        logging.info("PrintToPSFile %s" % str(bb))
         padding = 15
         x = bb[0] - padding
         y = bb[1] - padding
@@ -1534,7 +1532,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
 ##"""
 
 ##        file = open(fileName,'w')
-##        if animation is not None:
+##        if animation != None:
 ##            anivar = ",\n".join(animation)
 ##            vars = {'x':x, 'y':y, 'width':width, 'height':height, 'animation':anivar}
 ##            file.write(animationhead % vars)
@@ -1744,7 +1742,7 @@ class GraphDisplayFrame(GraphDisplay, Frame):
         GraphDisplay.__init__(self)
         
     def SetTitle(self,title):
-        log.info("change window title to %s" % title)
+        logging.info("change window title to %s" % title)
 
     def Show(self):
         pass
