@@ -29,8 +29,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 820 $ 
+#                       from $Date: 2020-12-16 14:45:18 +0100 (Wed, 16 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -365,7 +365,7 @@ class GraphEditor(GraphDisplay):
                     
                 d = EditWeightsDialog(self, "Weight of edge (%d,%d)" % (tail,head), 
                                       count, weights, intFlag) 
-                if d.result is not None:
+                if d.result != None:
                     for i in xrange(count):
                         self.SetEdgeWeight(i, tail, head, d.result[i])
             else: # We have a vertex
@@ -380,7 +380,7 @@ class GraphEditor(GraphDisplay):
                         
                     d = EditWeightsDialog(self, "Edit vertex weights %d" % v, 
                                               count, weights, intFlag) 
-                    if d.result is not None:
+                    if d.result != None:
                         for i in xrange(count):
                             self.G.SetVertexWeight(i, v, d.result[i])
                             
