@@ -29,21 +29,19 @@
 #
 #
 #
-#       This file is version $Revision: 806 $
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 826 $
+#                       from $Date: 2020-12-17 16:18:34 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $
 #
 ################################################################################
 
 import types
 import StringIO
-from string import split
 import string
 from GatoGlobals import *
 import Graph
 from DataStructures import Point2D, VertexLabeling, EdgeLabeling, EdgeWeight, VertexWeight, Queue
 import logging
-log = logging.getLogger("Gato")
 
 
 ################################################################################
@@ -114,7 +112,7 @@ def ConnectedComponents(G):
         visited[v] = None
         
     for root in G.vertices:
-        if visited[root] is not None:
+        if visited[root] != None:
             continue
         else: # Found a new component
             component = [root]
@@ -286,7 +284,7 @@ def OpenCATBoxGraph(_file):
     
     # get file from name or file object
     graphFile=None
-    if type(_file) in types.StringTypes:
+    if type(_file) in (str,):
         graphFile = open(_file, 'r')
     elif type(_file)==types.FileType or issubclass(_file.__class__,StringIO.StringIO):
         graphFile=_file
@@ -300,6 +298,13 @@ def OpenCATBoxGraph(_file):
     firstEdgeLineNr   = -1
     lastEdgeLineNr    = -1
     intWeights        = 0
+
+    def int_value(s):
+        return int(s.split(':')[1])
+
+    def	float_value(s):
+        return float(s.split(':')[1])
+
     
     while 1:
     
@@ -309,13 +314,22 @@ def OpenCATBoxGraph(_file):
             break
             
         if lineNr == 2: # Read directed and euclidian
-            splitLine = split(line[:-1],';')	    
-            G.directed = eval(split(splitLine[0],':')[1])
-            G.simple = eval(split(splitLine[1],':')[1])
-            G.euclidian = eval(split(splitLine[2],':')[1])
-            intWeights = eval(split(splitLine[3],':')[1])
-            nrOfEdgeWeights = eval(split(splitLine[4],':')[1])
-            nrOfVertexWeights = eval(split(splitLine[5],':')[1])
+            # splitLine = split(line[:-1],';')	    
+            # G.directed = eval(split(splitLine[0],':')[1])
+            # G.simple = eval(split(splitLine[1],':')[1])
+            # G.euclidian = eval(split(splitLine[2],':')[1])
+            # intWeights = eval(split(splitLine[3],':')[1])
+            # nrOfEdgeWeights = eval(split(splitLine[4],':')[1])
+            # nrOfVertexWeights = eval(split(splitLine[5],':')[1])
+
+            splitLine = line[:-1].split(';')
+            G.directed = int_value(splitLine[0])
+            G.simple = int_value(splitLine[1])
+            G.euclidian = int_value(splitLine[2])
+            intWeights = int_value(splitLine[3])
+            nrOfEdgeWeights = int_value(splitLine[4])
+            nrOfVertexWeights = int_value(splitLine[5])
+
             for i in xrange(nrOfEdgeWeights):
                 G.edgeWeights[i] = EdgeWeight(G)
             for i in xrange(nrOfVertexWeights):
@@ -323,34 +337,41 @@ def OpenCATBoxGraph(_file):
                 
                 
         if lineNr == 5: # Read nr of vertices
-            nrOfVertices = eval(split(line[:-2],':')[1]) # Strip of "\n" and ; 
+            nrOfVertices = int_value(line[:-2]) # Strip of "\n" and ; 
             firstVertexLineNr = lineNr + 1
             lastVertexLineNr  = lineNr + nrOfVertices
             
         if  firstVertexLineNr <= lineNr and lineNr <= lastVertexLineNr: 
-            splitLine = split(line[:-1],';')
+            splitLine = line[:-1].split(';')
             v = G.AddVertex()
-            x = eval(split(splitLine[1],':')[1])
-            y = eval(split(splitLine[2],':')[1])
+            x = int_value(splitLine[1])
+            y = int_value(splitLine[2])
             for i in xrange(nrOfVertexWeights):
-                w = eval(split(splitLine[3+i],':')[1])
+                if intWeights:
+                    w = int_value(splitLine[3+i])
+                else:
+                    w = float_value(splitLine[3+i])
                 G.vertexWeights[i][v] = w
                 
             E[v] = Point2D(x,y)
             
         if lineNr == lastVertexLineNr + 1: # Read Nr of edges
-            nrOfEdges = eval(split(line[:-2],':')[1]) # Strip of "\n" and ; 
+            nrOfEdges = int_value(line[:-2]) # Strip of "\n" and ; 
             firstEdgeLineNr = lineNr + 1
             lastEdgeLineNr  = lineNr + nrOfEdges
             
         if firstEdgeLineNr <= lineNr and lineNr <= lastEdgeLineNr: 
-            splitLine = split(line[:-1],';')
-            h = eval(split(splitLine[0],':')[1])
-            t = eval(split(splitLine[1],':')[1])
+            splitLine = line[:-2].split(';')
+            h = int_value(splitLine[0])
+            t = int_value(splitLine[1])
             G.AddEdge(t,h,False)
             for i in xrange(nrOfEdgeWeights):
-                G.edgeWeights[i][(t,h)] = eval(split(splitLine[3+i],':')[1])
-                
+                # XXX Unclear whether intWeights is for both edge and vertex weights
+                if intWeights:
+                    G.edgeWeights[i][(t,h)] = int_value(splitLine[3+i])
+                else:
+                    G.edgeWeights[i][(t,h)] = float_value(splitLine[3+i])
+
         lineNr = lineNr + 1
         
     graphFile.close()
@@ -372,7 +393,7 @@ def SaveCATBoxGraph(G, _file):
     
     # get file from name or file object
     file=None
-    if type(_file) in types.StringTypes:
+    if type(_file) in (str,):
         file = open(_file, 'w')
     elif type(_file)==types.FileType or issubclass(_file.__class__,StringIO.StringIO):
         file=_file
@@ -389,7 +410,7 @@ def SaveCATBoxGraph(G, _file):
                nrOfEdgeWeights, nrOfVertexWeights))
     file.write("scroller:\n")
     file.write("vdim:1000; hdim:1000; vlinc:10; hlinc:10; vpinc:50; hpinc:50;\n")
-    file.write("vertices:" + `G.Order()` + ";\n")
+    file.write("vertices:" + repr(G.Order()) + ";\n")
 
     # Being paranoid here: We force edge weights to be euclidean 
     if G.QEuclidian():
@@ -409,7 +430,7 @@ def SaveCATBoxGraph(G, _file):
                 file.write(" w:%d;" % G.vertexWeights[i][v])	    
         file.write("\n")
         
-    file.write("edges:" + `G.Size()` + ";\n")
+    file.write("edges:" + repr(G.Size()) + ";\n")
     for tail in G.vertices:
         for head in G.OutNeighbors(tail):
             file.write("h:%d; t:%d; e:2;" % (save[head], save[tail]))
@@ -448,7 +469,7 @@ def ParseGML(file):
                 retval.append((token[0], token[1]))
                 
         else:
-            log.error("Serious format error line %s:" % line)
+            logging.error("Serious format error line %s:" % line)
             
             
 def PairListToDictionary(l):
@@ -475,7 +496,7 @@ def OpenGMLGraph(fileName):
     file.close()
     
     if g[0][0] != 'graph':
-        log.error("Serious format error in %s. first key is not graph" % fileName)
+        logging.error("Serious format error in %s. first key is not graph" % fileName)
         return
     else:
         l = g[0][1]
@@ -547,7 +568,7 @@ def OpenDotGraph(fileName):
     dot2graph = {}
     
     for l in lines[3:]:
-        items = string.split(l)
+        items = l.split(l)
         if len(items) < 2:
             break
         if items[1] != '->':
