@@ -29,8 +29,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 821 $ 
+#                       from $Date: 2020-12-16 15:32:12 +0100 (Wed, 16 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -361,7 +361,7 @@ class SAGraphEditor(GraphEditor, Frame):
         
     def EnterButtonCallback(self,e):
         w = e.widget
-        text = string.join(w.config("text")[4])
+        text = " ".join(w.config("text")[4])
         self.UpdateInfo(text)
         value = w.config("value")[4]
         w.configure(image=self.icons[value][1])
@@ -603,7 +603,7 @@ class SAGraphEditor(GraphEditor, Frame):
             elif e == 'dotted':
                 G = OpenDotGraph(fileName)
             else:
-                log.error("Unknown extension %s" % e)
+                logging.error("Unknown extension %s" % e)
                 
             if not self.gridding:
                 self.graphMenu.invoke(self.graphMenu.index('Grid'))	
@@ -697,7 +697,7 @@ class SAGraphEditor(GraphEditor, Frame):
                                      defaultextension=".svg",
                                      filetypes = [("SVG", ".svg")]
                                      )
-        if fileName is not "":
+        if fileName != "":
             import GatoExport
             GatoExport.ExportGraphToSVG(fileName, None, self)
             
@@ -802,7 +802,7 @@ class SAGraphEditor(GraphEditor, Frame):
     #----- Tools Menu callbacks
     def ChangeTool(self):
         tool = self.toolVar.get()
-        if self.lastTool is not None:
+        if self.lastTool != None:
             self.buttons[self.lastTool].configure(image=self.icons[self.lastTool][0])
         self.SetEditMode(tool)
         self.lastTool = tool
@@ -926,7 +926,7 @@ class SAGraphEditorToplevel(SAGraphEditor, Toplevel):
                                                ,("Postscript", ".ps")
                                              ]
                                  )
-        if file is not "": 
+        if file != "": 
             self.PrintToPSFile(file)
         self.tkraise()
         self.focus_force()
@@ -954,7 +954,6 @@ class Start:
         graphEditor.dirty = 0
         graphEditor.NewGraph()
         import logging
-        log = logging.getLogger("Gred.py")
 
         
         ################################################################################
@@ -987,7 +986,6 @@ def main(argv=None):
     else:
         graphEditor.NewGraph()
     import logging
-    log = logging.getLogger("Gred.py")
 
     # On MacOS X the Quit menu entry otherwise bypasses our Quit
     # Handler According to
