@@ -30,8 +30,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 820 $ 
+#                       from $Date: 2020-12-16 14:45:18 +0100 (Wed, 16 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -39,6 +39,7 @@
 import GatoGlobals
 import AnimationHistory
 import traceback
+import logging
 
 g = GatoGlobals.AnimationParameters
 
@@ -51,7 +52,6 @@ class MergedHistories:
         self.history_index = None
         self.animator1 = None
         self.animator2 = None
-        self.auto_print = 0
 
     def _check_animator_set(self, animator, display):
         if self.animator1 is None:
@@ -263,7 +263,7 @@ class MergedHistories:
         self.append(animation, display)
         
     def __getattr__(self,arg):
-        print "Function tried to be called: ", arg
+        logging.warning("Function tried to be called: %s " % str(arg))
         raise AttributeError('Specified function of MergedHistories does not exist.')
             
     def Undo(self):
@@ -290,7 +290,7 @@ class MergedHistories:
             
     def DoAll(self):
         # Catchup
-        if self.history_index is not None:
+        if self.history_index != None:
             for cmd, display in self.history[self.history_index:]:     #formerly time, cmd
                 if cmd.canUndo:
                     #if cmd cannot undo, then it is the one blocking further undoes, do not do command
@@ -327,8 +327,16 @@ class MergedHistories:
                 raise Error("Displaynum of function in merged history is neither 1 nor 2.")
             
     def append(self, animation, display):
-        if self.auto_print:
-           print "disp" , display , "  " , animation.log_str() 
+        message = "disp%d %s" % (display, animation.log_str())
+        logging.debug(message)
+
+        # In some algorithms the first animation commands occurr in secondary
+        # graph display. Then self,animator1 is not set.
+        if self.animator1 and self.animator1.animationReportFileHandle:
+            self.animator1.animationReportFileHandle.write(message + "\n")
+        elif self.animator2 and self.animator2.animationReportFileHandle:
+            self.animator2.animationReportFileHandle.write(message + "\n")
+            
         tup = animation, display
         self.history.append(tup)
         
