@@ -5,7 +5,9 @@
 #	file:   ObjectGraph.py
 #	author: Alexander Schliep (alexander@schlieplab.org)
 #
-#       Copyright (C) 2007-2015 Alexander Schliep, Winfried Hochstaettler
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
 #       Contact: alexander@schlieplab.org             
 #
@@ -26,8 +28,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 826 $ 
+#                       from $Date: 2020-12-17 16:18:34 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -37,7 +39,6 @@ from DataStructures import Point2D, VertexLabeling, EdgeLabeling, EdgeWeight
 #from math import log
 
 import logging
-log = logging.getLogger("ObjectGraph.py")
 
 ################################################################################
 #
@@ -152,11 +153,11 @@ class ObjectGraph(object):
             are distinct edges """
         
         if self.simple == 1 and tail == head: # Loop
-            raise GraphNotSimpleError, '(%d,%d) is a loop' % (tail,head)
-        if self.directed == 0 and self.edges.has_key((head,tail)):
-            raise GraphNotSimpleError, '(%d,%d) is already an undirected edge' % (head,tail)
-        if self.edges.has_key((tail,head)): # Multiple edge
-            raise GraphNotSimpleError, '(%d,%d) is already an directed edge' % (tail,head)
+            raise GraphNotSimpleError("(%d,%d) is a loop" % (tail,head))
+        if self.directed == 0 and (head,tail) in self.edges:
+            raise GraphNotSimpleError("(%d,%d) is already an undirected edge" % (head,tail))
+        if (tail,head) in self.edges: # Multiple edge
+            raise GraphNotSimpleError("(%d,%d) is already an directed edge" % (tail,head))
 
         e = self.edgeClass(self.vertices[tail],self.vertices[head])
         self.edges[(tail,head)] = e
@@ -180,7 +181,7 @@ class ObjectGraph(object):
         try:
             e = self.edges[(tail,head)]
         except KeyError:
-            raise NoSuchEdgeError, "(%d,%d) is not an edge." % (tail,head)
+            raise NoSuchEdgeError("(%d,%d) is not an edge." % (tail,head))
 
         self.vertices[tail].outEdges.remove(e)
         self.vertices[head].inEdges.remove(e)
@@ -192,23 +193,23 @@ class ObjectGraph(object):
              vertices as (tail,head). Raises NoSuchEdgeError upon error. """
         
         if tail not in self.vertices.keys() or head not in self.vertices.keys():
-            raise NoSuchEdgeError, "(%d,%d) is not an edge." % (tail,head)
+            raise NoSuchEdgeError("(%d,%d) is not an edge." % (tail,head))
             
-        if self.edges.has_key((tail,head)):
+        if (tail,head) in self.edges:
             return (tail,head)
-        elif self.directed == 0 and self.edges.has_key((head,tail)):
+        elif self.directed == 0 and (head,tail) in self.edges:
             return (head,tail)
         else:
-            raise NoSuchEdgeError, "(%d,%d) is not an edge." % (tail,head)
+            raise NoSuchEdgeError("(%d,%d) is not an edge." % (tail,head))
             
             
     def QEdge(self,tail,head):
         """ Returns 1 if (tail,head) is an edge in G. If G is undirected
             order of vertices does not matter """
         if self.directed == 1:	
-            return self.edges.has_key((tail,head))
+            return (tail,head) in self.edges
         else: 
-            return self.edges.has_key((tail,head)) or self.edges.has_key((head,tail))
+            return (tail,head) in self.edges or (head,tail) in self.edges
 
 
     def QEdgeWidth(self):
@@ -512,7 +513,7 @@ class ObjectGraph(object):
 ##        """ Add subgraph G to self. Will do nothing if self and G 
 ##            have distinct supergraphs """
 ##        if self.superGraph != G.superGraph:
-##            log.error("AddSubGraph: distinct superGraphs")
+##            logging.error("AddSubGraph: distinct superGraphs")
 ##            return
 ##        for v in G.vertices:
 ##            self.AddVertex(v)
@@ -543,7 +544,7 @@ class ObjectGraph(object):
         
 ##    def GetNextVertexID(self):
 ##        """ *Internal* safeguard """
-##        log.error("Induced Subgraph -> GetNextVertexID should never have been called")
+##        logging.error("Induced Subgraph -> GetNextVertexID should never have been called")
         
 ##    def Weight(self):
 ##        """ Returns the total weight (= sum of edge weights) of subgraph """
