@@ -6,11 +6,12 @@
 #	file:   ObjectGred.py
 #	author: Alexander Schliep (alexander@schlieplab.org)
 #
-#       Copyright (C) 2007-2015 Alexander Schliep, Winfried Hochstaettler
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
 #       Contact: alexander@schlieplab.org
 #
-
 #
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
@@ -28,8 +29,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 821 $ 
+#                       from $Date: 2020-12-16 15:32:12 +0100 (Wed, 16 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -349,7 +350,7 @@ class SAGraphEditor(GraphEditor, Frame):
         
     def EnterButtonCallback(self,e):
         w = e.widget
-        text = string.join(w.config("text")[4])
+        text = " ".join(w.config("text")[4])
         self.UpdateInfo(text)
         value = w.config("value")[4]
         w.configure(image=self.icons[value][1])
@@ -566,7 +567,7 @@ class SAGraphEditor(GraphEditor, Frame):
             elif e == 'dotted':
                 G = OpenDotGraph(file)
             else:
-                log.error("Unknown extension %s" % e)
+                logging.error("Unknown extension %s" % e)
                 
             if not self.gridding:
                 self.graphMenu.invoke(self.graphMenu.index('Grid'))	
@@ -633,7 +634,7 @@ class SAGraphEditor(GraphEditor, Frame):
                                                #,("Graphlet", ".let")
                                              ]
                                  )
-        if file is not "":
+        if file != "":
             self.fileName = file
             self.dirty = 0
             SaveCATBoxGraph(self.G,file)
@@ -647,7 +648,7 @@ class SAGraphEditor(GraphEditor, Frame):
                                                ,("Postscript", ".ps")
                                              ]
                                  )
-        if file is not "": 
+        if file != "": 
             self.PrintToPSFile(file)
             
             
@@ -745,7 +746,7 @@ class SAGraphEditor(GraphEditor, Frame):
                 #----- Tools Menu callbacks
     def ChangeTool(self):
         tool = self.toolVar.get()
-        if self.lastTool is not None:
+        if self.lastTool != None:
             self.buttons[self.lastTool].configure(image=self.icons[self.lastTool][0])
         self.SetEditMode(tool)
         self.lastTool = tool
@@ -804,7 +805,7 @@ class SAGraphEditorToplevel(SAGraphEditor, Toplevel):
                                                ,("Postscript", ".ps")
                                              ]
                                  )
-        if file is not "": 
+        if file != "": 
             self.PrintToPSFile(file)
         self.tkraise()
         self.focus_force()
@@ -831,7 +832,6 @@ class Start:
         graphEditor = SAGraphEditorToplevel()
         graphEditor.NewGraph()
         import logging
-        log = logging.getLogger("Gred.py")
         
         ################################################################################
 if __name__ == '__main__':
@@ -852,6 +852,5 @@ if __name__ == '__main__':
     graphEditor = SAGraphEditor(tk)
     graphEditor.NewGraph()
     import logging
-    log = logging.getLogger("Gred.py")
     graphEditor.mainloop()
     
