@@ -6,12 +6,13 @@
 #	file:   ProbEditorContinuous.py
 #	author: Achim Gaedke (achim.gaedke@zpr.uni-koeln.de)
 #
-#       Copyright (C) 1998-2002, Alexander Schliep, Winfried Hochstaettler and
+#       Copyright (C) 2016-2020 Alexander Schliep and
+#	Copyright (C) 1998-2015 Alexander Schliep, Winfried Hochstaettler and 
 #       Copyright (C) 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
+#                                   
 #
 #       Contact: alexander@schlieplab.org
 #
-
 #
 #       This library is free software; you can redistribute it and/or
 #       modify it under the terms of the GNU Library General Public
@@ -29,8 +30,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 826 $
+#                       from $Date: 2020-12-17 16:18:34 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -44,7 +45,7 @@ import ProbEditorBasics
 import ProbEditorWidgets
 from Tkconstants import *
 import tkMessageBox
-
+import logging
 
 class plot_object:
     """
@@ -1068,7 +1069,7 @@ class plot_canvas(Tkinter.Canvas):
         """
         if self.find_plot_object(plot_object)!=None:
             # exists!
-            print 'exists'
+            logging.error("Object already exists!")
             return
         item=self.create_plot_item(plot_object)
         self.plot_objects.append((plot_object,item))
@@ -1111,7 +1112,7 @@ class handle_base:
         """
         self.canvas=canvas
         self.values=values
-        if report_function is not None:
+        if report_function != None:
             self.report_function=report_function
         else:
             self.report_function=None
@@ -1195,7 +1196,7 @@ class handle_base:
         event handler for moving this handle
         """
         new_values=self.values_from_mouse(event)
-        if new_values is not None:
+        if new_values != None:
             self.set_values(new_values)
             self.report('move')
         return
@@ -1233,7 +1234,7 @@ class handle_base:
         """
         call report function
         """
-        if self.report_function is not None:
+        if self.report_function != None:
             self.report_function(self,reason,self.get_values())
 
             ################################################################################
@@ -1331,8 +1332,8 @@ class box_handle(handle_base):
            self.box_line==current:
             handle_base.start_move_event(self,event)
         else:
-            print self.start_move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.start_move_event.__name__)
+            
         return
 
     def values_from_mouse(self,event):
@@ -1352,8 +1353,8 @@ class box_handle(handle_base):
             diff=abs(self.values[1]-self.values[0])/2.0
             values=(v-diff,v+diff)
         else:
-            print self.move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.start_move_event.__name__)
+
         return values
 
         ####################################################################################
@@ -1448,8 +1449,8 @@ class exp_handle(handle_base):
            self.box_line==current:
             handle_base.start_move_event(self,event)
         else:
-            print self.start_move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.start_move_event.__name__)
+
         return
 
     def values_from_mouse(self,event):
@@ -1469,8 +1470,8 @@ class exp_handle(handle_base):
             diff=abs(self.values[1]-self.values[0])/2.0
             values=(v-diff,v+diff)
         else:
-            print self.move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.move_event.__name__)
+
         return values
 
 
@@ -1564,8 +1565,8 @@ class exp_other_handle(handle_base):
            self.box_line==current:
             handle_base.start_move_event(self,event)
         else:
-            print self.start_move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.start_move_event.__name__)
+
         return
 
     def values_from_mouse(self,event):
@@ -1585,8 +1586,8 @@ class exp_other_handle(handle_base):
             diff=abs(self.values[1]-self.values[0])/2.0
             values=(v-diff,v+diff)
         else:
-            print self.move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.move_event.__name__)
+
         return values
 
 
@@ -1699,8 +1700,8 @@ class gaussian_handle(handle_base):
            self.sigma2_handle==current:
             handle_base.start_move_event(self,event)
         else:
-            print self.start_move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.start_move_event.__name__)
+
         return
 
     def values_from_mouse(self,event):
@@ -1718,8 +1719,7 @@ class gaussian_handle(handle_base):
             if v!=self.values[0]:
                 values=(self.values[0],abs(v-self.values[0]))
         else:
-            print self.move_event.__name__,\
-                  ": don't know what to do with this event"
+            logging.warning("%s: don't know what to do with this event." % self.move_event.__name__)
         return values
 
 class gaussian_tail_handle_right(gaussian_handle):
@@ -1732,7 +1732,7 @@ class gaussian_tail_handle_right(gaussian_handle):
         """
         self.tail=values[2]
         values=(values[0],values[1])
-        if conf.has_key('arg_dict'):
+        if 'arg_dict' in conf:
             conf.update(conf['arg_dict'])
         gaussian_handle.__init__(self,canvas,report_function,values,arg_dict=conf)
 
@@ -1798,7 +1798,7 @@ class gaussian_tail_handle_right(gaussian_handle):
             return (self.values[0],self.values[1],v)
         else:
             values=gaussian_handle.values_from_mouse(self,event)
-            if values is not None:
+            if values != None:
                 return (values[0],values[1],self.tail)
             else:
                 return None
@@ -2424,7 +2424,8 @@ class gauss_editor(Tkinter.Frame):
             self.handle_list.append(handle)
 
         else:
-            print "no handle for %s"%(o.__class__.__name__)
+            logging.warning("no handle for %s" % (o.__class__.__name__))
+
         self.pos+=10
 
 
@@ -2456,7 +2457,7 @@ class gauss_editor(Tkinter.Frame):
             self.max_plot_x=plot_x[0]
             self.min_plot_x=plot_x[1]
         else:
-            print "Error"
+            logging.error("Error. Something went wrong.")
 
         if plot_y[1]>plot_y[0]:
             self.max_plot_y=plot_y[1]
@@ -2466,7 +2467,8 @@ class gauss_editor(Tkinter.Frame):
             self.max_plot_y=plot_y[0]
             self.min_plot_y=plot_y[1]
         else:
-            print "Error"
+            logging.error("Error. Something went wrong.")
+
 
         #Intervall
         self.int_x=(self.max_plot_x-self.min_plot_x)/10.0
