@@ -25,8 +25,8 @@
 #       License along with this library; if not, write to the Free
 #       Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 826 $ 
+#                       from $Date: 2020-12-17 16:18:34 +0100 (Thu, 17 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -39,6 +39,7 @@ import os.path
 import codecs
 import xml.dom
 import xml.dom.minidom
+import logging
 
 class Node:
     """
@@ -122,8 +123,7 @@ class Node:
             self.canvas.itemconfigure(self.iconItem,anchor=Tkinter.W)
             # maintain selection
         if self.selected:
-            coords=apply(self.canvas.bbox,
-                         filter(None,[self.iconItem,self.nameItem]))
+            coords=self.canvas.bbox(*filter(None,[self.iconItem,self.nameItem]))
             if self.selectionItem:
                 self.canvas.coords(self.selectionItem,coords)
             else:
@@ -176,7 +176,7 @@ class Node:
             return None
         items=self.getAllItems()
         if items:
-            return apply(self.canvas.bbox,items)
+            return self.canvas.bbox(*items)
         else:
             return (self.anchor[0],self.anchor[1],self.anchor[0],self.anchor[1])
             
@@ -213,8 +213,7 @@ class Node:
         """
         self.selected=1
         if self.canvas:
-            coords=apply(self.canvas.bbox,
-                         filter(None,[self.iconItem,self.nameItem]))
+            coords=self.canvas.bbox(*filter(None,[self.iconItem,self.nameItem]))
             if self.selectionItem:
                 self.canvas.coords(self.selectionItem,coords)
             else:
@@ -248,7 +247,7 @@ class Leaf(Node):
     defaultIconData="R0lGODlhDAAMAKEAALLA3AAAAP//8wAAACH5BAEAAAAALAAAAAAMAAwAAAIgRI4Ha+IfWHsOrSASvJTGhnhcV3EJlo3kh53ltF5nAhQAOw=="
     
     def __init__(self,parent=None, anchor=(0,0), name=None, icon=None):
-        if not Leaf.__dict__.has_key("defaultIcon"):
+        if "defaultIcon" not in Leaf.__dict__:
             Leaf.defaultIcon=Tkinter.PhotoImage(data=Leaf.defaultIconData)
         if name==None:
             raise Exception("name should be text")
@@ -283,9 +282,9 @@ class Branch(Node):
         children can be specified...
         """
         # initialise Icon Data
-        if not Branch.__dict__.has_key("expandImage"):
+        if "expandImage" not in Branch.__dict__:
             Branch.expandImage=Tkinter.BitmapImage(data=Branch.expandData)
-        if not Branch.__dict__.has_key("collapseImage"):
+        if "collapseImage" not in Branch.__dict__:
             Branch.collapseImage=Tkinter.BitmapImage(data=Branch.collapseData)
         self.expanded=expanded
         icon=Branch.expandImage
@@ -333,7 +332,7 @@ class Branch(Node):
         if self.expanded:
             self.icon=self.collapseImage
             Node.display(self,recursive+1)
-            (x0,y0,x1,y1)=apply(self.canvas.bbox,filter(None,[self.nameItem,self.iconItem]))
+            (x0,y0,x1,y1)=self.canvas.bbox(*filter(None,[self.nameItem,self.iconItem]))
             (ix0,iy0,ix1,iy1)=self.canvas.bbox(self.iconItem)
             self.updateChildList()
             for child in self.children:
@@ -405,7 +404,7 @@ class Branch(Node):
         xoffset=yoffset=0
         if items:
             # move them...
-            (ox1,oy1,ox2,oy2)=apply(self.canvas.bbox,items)
+            (ox1,oy1,ox2,oy2)=self.canvas.bbox(*items)
             yoffset=ny2+1-oy1
             # really nothing to do, because geometry not changed
             if yoffset==0 and xoffset==0:
@@ -447,7 +446,7 @@ class DirBranch(Branch):
         instantiate a directory entry
         """
         Branch.__init__(self,parent=parent, anchor=anchor, name=name, expanded=expanded)
-        self.path=apply(os.path.join,self.getNamePath())
+        self.path=os.path.join(*self.getNamePath())
         if not os.path.exists(self.path):
             raise Exception("Path %s does not exist"%self.path)
             
@@ -549,7 +548,7 @@ class xmlElementBranch(Branch):
         print map(lambda c:c.name, self.children)
         
     def __del__(self):
-        print "DOM Element %s deleted"%self.name
+        logging.info("DOM Element %s deleted" % self.name)
         
 class xmlFileBranch(xmlElementBranch):
     """
@@ -559,7 +558,7 @@ class xmlFileBranch(xmlElementBranch):
     
         pathList=parent.getNamePath()
         pathList.append(name)
-        self.path=apply(os.path.join,pathList)
+        self.path=os.path.join(*pathList)
         if not os.path.isfile(self.path):
             raise Exception("file %s does not exist"%self.path)
             
@@ -567,7 +566,7 @@ class xmlFileBranch(xmlElementBranch):
         try:
             # pull dom out of file
             self.dom = xml.dom.minidom.parse(self.path)
-        except xml.dom.DOMException, e:
+        except xml.dom.DOMException as e:
             self.dom=None
             
         xmlElementBranch.__init__(self,
@@ -578,7 +577,7 @@ class xmlFileBranch(xmlElementBranch):
                                   element=self.dom.documentElement)
         
     def __del__(self):
-        print "DOM of file %s deleted"%self.path
+        logging.info("DOM of file %s deleted" % self.path)
         xmlElementBranch.__del__(self)
         
 class Tree(Tkinter.Canvas):
@@ -623,70 +622,70 @@ class scrolledTree(Tree):
         self.config(scrollregion=self.bbox(Tkinter.ALL))
         
     def pack(self,*args,**kws):
-        apply(self.hiddenFrame.pack,args,kws)
+        self.hiddenFrame.pack(*args, **kws)
         
     def pack_configure(self,*args,**kws):
-        apply(self.hiddenFrame.pack_configure,args,kws)
+        self.hiddenFrame.pack_configure(*args, **kws)
         
     def pack_forget(self,*args,**kws):
-        apply(self.hiddenFrame.pack_forget,args,kws)
+        self.hiddenFrame.pack_forget(*args, **kws)
         
     def pack_info(self,*args,**kws):
-        apply(self.hiddenFrame.pack_info,args,kws)
+        self.hiddenFrame.pack_info(*args, **kws)
         
     def pack_propagate(self,*args,**kws):
-        apply(self.hiddenFrame.pack_propagate,args,kws)
+        self.hiddenFrame.pack_propagate(*args, **kws)
         
     def pack_slaves(self,*args,**kws):
-        apply(self.hiddenFrame.pack_slaves,args,kws)
+        self.hiddenFrame.pack_slaves(*args, **kws)
         
     def place(self,*args,**kws):
-        apply(self.hiddenFrame.place,args,kws)
+        self.hiddenFrame.place(*args, **kws)
         
     def place_configure(self,*args,**kws):
-        apply(self.hiddenFrame.place_configure,args,kws)
+        self.hiddenFrame.place_configure(*args, **kws)
         
     def place_forget(self,*args,**kws):
-        apply(self.hiddenFrame.place_forget,args,kws)
+        self.hiddenFrame.place_forget(*args, **kws)
         
     def place_info(self,*args,**kws):
-        apply(self.hiddenFrame.place_info,args,kws)
+        self.hiddenFrame.place_info(*args, **kws)
         
     def place_slaves(self,*args,**kws):
-        apply(self.hiddenFrame.place_slaves,args,kws)
+        self.hiddenFrame.place_slaves(*args, **kws)
         
     def grid(self,*args,**kws):
-        apply(self.hiddenFrame.grid,args,kws)
+        self.hiddenFrame.grid(*args, **kws)
         
     def grid_configure(self,*args,**kws):
-        apply(self.hiddenFrame.grid_configure,args,kws)
+        self.hiddenFrame.grid_configure(*args, **kws)
         
     def grid_forget(self,*args,**kws):
-        apply(self.hiddenFrame.grid_forget,args,kws)
+        self.hiddenFrame.grid_forget(*args, **kws)
         
     def grid_remove(self,*args,**kws):
-        apply(self.hiddenFrame.grid_remove,args,kws)
+        self.hiddenFrame.grid_remove(*args, **kws)
         
     def grid_info(self,*args,**kws):
-        apply(self.hiddenFrame.grid_info,args,kws)
+        self.hiddenFrame.grid_info(*args, **kws)
         
     def grid_propagate(self,*args,**kws):
-        apply(self.hiddenFrame.grid_propagate,args,kws)
+        self.hiddenFrame.grid_propagate(*args, **kws)
         
     def grid_slaves(self,*args,**kws):
-        apply(self.hiddenFrame.grid_slaves,args,kws)
+        self.hiddenFrame.grid_slaves(*args, **kws)
         
     def columnconfigure(self,*args,**kws):
-        apply(self.hiddenFrame.columnconfigure,args,kws)
+        self.hiddenFrame.columnconfigure(*args, **kws)
         
     def rowconfigure(self,*args,**kws):
-        apply(self.hiddenFrame.rowconfigure,args,kws)
+        self.hiddenFrame.rowconfigure(*args, **kws)
         
     def grid_location(self,*args,**kws):
-        apply(self.hiddenFrame.grid_location,args,kws)
+        self.hiddenFrame.grid_location(*args, **kws)
         
     def grid_size(self,*args,**kws):
-        apply(self.hiddenFrame.grid_size,args,kws)
+        self.hiddenFrame.grid_size(*args, **kws)
         
 class WorkInProgress(scrolledTree):
 
