@@ -31,8 +31,8 @@
 #
 #
 #
-#       This file is version $Revision: 806 $ 
-#                       from $Date: 2020-12-08 15:13:58 +0100 (Tue, 08 Dec 2020) $
+#       This file is version $Revision: 808 $ 
+#                       from $Date: 2020-12-08 17:22:52 +0100 (Tue, 08 Dec 2020) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -57,7 +57,7 @@ else:
     # Some variant of exec(open("GatoGlobals.py").read())
     raise NotImplementedError
 
-long_description_text = open('README').readlines()
+long_description_text = "".join(open('README').readlines())
 
 
 setup(name="Gato",
